# -*- coding: utf-8 -*-

import re
import unittest

from pokinator import Pokinator


class NameGenTest(unittest.TestCase):
    def test_generate(self):
        self.assertTrue(re.match(r'\w+-\w+-\d+', Pokinator.generate()))

    def test_generate_lowercase(self):
        self.assertTrue(re.match(r'[a-z]+-[a-z]+-\d+', Pokinator.generate(lowercase=True)))

    def test_generate_generation(self):
        for i in range(1, 7):
            self.assertTrue(re.match(r'\w+-\w+-\d+', Pokinator.generate(generation=i)))

    def test_not_equal_in_repeated_call(self):
        self.assertNotEqual(Pokinator.generate(), Pokinator.generate())

    def test_configurable_range(self):
        self.assertTrue(re.match(r'\w+-\w+-\d$', Pokinator.generate(9)))

    def test_wrong_generation(self):
        with self.assertRaises(RuntimeError):
            Pokinator.generate(generation=0)
        with self.assertRaises(RuntimeError):
            Pokinator.generate(generation=8)

    def test_wrong_range(self):
        with self.assertRaises(RuntimeError):
            Pokinator.generate('1')
        with self.assertRaises(RuntimeError):
            Pokinator.generate(-1)

    def test_wrong_delimiter(self):
        with self.assertRaises(RuntimeError):
            Pokinator.generate(delimiter=1)

    def test_wrong_digit(self):
        with self.assertRaises(RuntimeError):
            Pokinator.generate(digit=3)
            Pokinator.generate(token_range=999, digit=4)


def run_test():
    print('#1 value test : ' + Pokinator.generate())
    print('#2 value test : ' + Pokinator.generate(9))
    print('#3 value test : ' + Pokinator.generate(delimiter='*'))
    print('#4 value test : ' + Pokinator.generate(token_range=999, digit=3))
    print('#5 value test : ' + Pokinator.generate(generation=2))
    print('#6 value test : ' + Pokinator.generate(lowercase=True))

    ts = unittest.makeSuite(NameGenTest,  'test')
    runner = unittest.TextTestRunner()
    runner.run(ts)



# -*- coding: utf-8 -*-

_name1 = [
    'Turtwig', 'Grotle', 'Torterra', 'Chimchar', 'Monferno',
    'Infernape', 'Piplup', 'Prinplup', 'Empoleon', 'Starly',
    'Staravia', 'Staraptor', 'Bidoof', 'Bibarel', 'Kricketot',
    'Kricketune', 'Shinx', 'Luxio', 'Luxray', 'Budew',
    'Roserade', 'Cranidos', 'Rampardos', 'Shieldon', 'Bastiodon',
    'Burmy', 'Wormadam', 'Mothim', 'Combee', 'Vespiquen',
    'Pachirisu', 'Buizel', 'Floatzel', 'Cherubi', 'Cherrim',
    'Shellos', 'Gastrodon', 'Ambipom', 'Drifloon', 'Drifblim',
    'Buneary', 'Lopunny', 'Mismagius', 'Honchkrow', 'Glameow',
    'Purugly', 'Chingling', 'Stunky', 'Skuntank', 'Bronzor',
    'Bronzong', 'Bonsly', 'Mime Jr.',
]

_name2 = [
    'Happiny', 'Chatot', 'Spiritomb', 'Gible', 'Gabite',
    'Garchomp', 'Munchlax', 'Riolu', 'Lucario', 'Hippopotas',
    'Hippowdon', 'Skorupi', 'Drapion', 'Croagunk', 'Toxicroak',
    'Carnivine', 'Finneon', 'Lumineon', 'Mantyke', 'Snover',
    'Abomasnow', 'Weavile', 'Magnezone', 'Lickilicky', 'Rhyperior',
    'Tangrowth', 'Electivire', 'Magmortar', 'Togekiss', 'Yanmega',
    'Leafeon', 'Glaceon', 'Gliscor', 'Mamoswine', 'Porygon-Z',
    'Gallade', 'Probopass', 'Dusknoir', 'Froslass', 'Rotom',
    'Uxie', 'Mesprit', 'Azelf', 'Dialga', 'Palkia', 'Heatran',
    'Regigigas', 'Giratina', 'Cresselia', 'Phione', 'Manaphy',
    'Darkrai', 'Shaymin', 'Arceus',
]



# -*- coding: utf-8 -*-

_name1 = [
    'Chespin', 'Quilladin', 'Chesnaught', 'Fennekin', 'Braixen',
    'Delphox', 'Froakie', 'Frogadier', 'Greninja', 'Bunnelby',
    'Diggersby', 'Fletchling', 'Fletchinder', 'Talonflame', 'Scatterbug',
    'Spewpa', 'Vivillon', 'Litleo', 'Pyroar', 'Flabebe',
    'Floette', 'Florges', 'Skiddo', 'Gogoat', 'Pancham',
    'Pangoro', 'Furfrou', 'Espurr', 'Meowstic', 'Honedge',
    'Doublade', 'Aegislash', 'Spritzee', 'Aromatisse', 'Swirlix',
    'Slurpuff',
]

_name2 = [
    'Inkay', 'Malamar', 'Binacle', 'Barbaracle', 'Skrelp',
    'Dragalge', 'Clauncher', 'Clawitzer', 'Helioptile', 'Heliolisk',
    'Tyrunt', 'Tyrantrum', 'Amaura', 'Aurorus', 'Sylveon',
    'Hawlucha', 'Dedenne', 'Carbink', 'Goomy', 'Sliggoo',
    'Goodra', 'Klefki', 'Phantump', 'Trevenant', 'Pumpkaboo',
    'Gourgeist', 'Bergmite', 'Avalugg', 'Noibat', 'Noivern',
    'Xerneas', 'Yveltal', 'Zygarde', 'Diancie', 'Hoopa',
    'Volcanion',
]



# -*- coding: utf-8 -*-

_name1 = [
    'Victini', 'Snivy', 'Servine', 'Serperior', 'Tepig',
    'Pignite', 'Emboar', 'Oshawott', 'Dewott', 'Samurott',
    'Patrat', 'Watchog', 'Lillipup', 'Herdier', 'Stoutland',
    'Purrloin', 'Liepard', 'Pansage', 'Simisage', 'Pansear',
    'Simisear', 'Panpour', 'Simipour', 'Munna', 'Musharna',
    'Pidove', 'Tranquill', 'Unfezant', 'Blitzle', 'Zebstrika',
    'Roggenrola', 'Boldore', 'Gigalith', 'Woobat', 'Swoobat',
    'Drilbur', 'Excadrill', 'Audino', 'Timburr', 'Gurdurr',
    'Conkeldurr', 'Tympole', 'Palpitoad', 'Seismitoad', 'Throh',
    'Sawk', 'Sewaddle', 'Swadloon', 'Leavanny', 'Venipede',
    'Whirlipede', 'Scolipede', 'Cottonee', 'Whimsicott', 'Petilil',
    'Lilligant', 'Basculin', 'Sandile', 'Krokorok', 'Krookodile',
    'Darumaka', 'Darmanitan', 'Maractus', 'Dwebble', 'Crustle',
    'Scraggy', 'Scrafty', 'Sigilyph', 'Yamask', 'Cofagrigus',
    'Tirtouga', 'Carracosta', 'Archen', 'Archeops', 'Trubbish',
    'Garbodor', 'Zorua', 'Zoroark',
]

_name2 = [
    'Minccino', 'Cinccino', 'Gothita', 'Gothorita', 'Gothitelle',
    'Solosis', 'Duosion', 'Reuniclus', 'Ducklett', 'Swanna',
    'Vanillite', 'Vanillish', 'Vanilluxe', 'Deerling', 'Sawsbuck',
    'Emolga', 'Karrablast', 'Escavalier', 'Foongus', 'Amoonguss',
    'Frillish', 'Jellicent', 'Alomomola', 'Joltik', 'Galvantula',
    'Ferroseed', 'Ferrothorn', 'Klink', 'Klang', 'Klinklang',
    'Tynamo', 'Eelektrik', 'Eelektross', 'Elgyem', 'Beheeyem',
    'Litwick', 'Lampent', 'Chandelure', 'Axew', 'Fraxure',
    'Haxorus', 'Cubchoo', 'Beartic', 'Cryogonal', 'Shelmet',
    'Accelgor', 'Stunfisk', 'Mienfoo', 'Mienshao', 'Druddigon',
    'Golett', 'Golurk', 'Pawniard', 'Bisharp', 'Bouffalant',
    'Rufflet', 'Braviary', 'Vullaby', 'Mandibuzz', 'Heatmor',
    'Durant', 'Deino', 'Zweilous', 'Hydreigon', 'Larvesta',
    'Volcarona', 'Cobalion', 'Terrakion', 'Virizion', 'Tornadus',
    'Thundurus', 'Reshiram', 'Zekrom', 'Landorus', 'Kyurem',
    'Keldeo', 'Meloetta', 'Genesect',
]



# -*- coding: utf-8 -*-

import re
from random import choice, randint
from .pokemons import firstgen
from .pokemons import secondgen
from .pokemons import thirdgen
from .pokemons import fourthgen
from .pokemons import fifthgen
from .pokemons import sixthgen
from .pokemons import seventhgen

RE_DASH = re.compile('-+')
RE_WORD = re.compile('[\W_]+')


class Pokinator:
    @classmethod
    def generate(self, token_range=9999, delimiter='-', digit=None, generation=1, lowercase=False):
        if not isinstance(token_range, int) or token_range < 0:
            raise RuntimeError('Token range must be a nonnegative integer')
        if not isinstance(delimiter, str):
            raise RuntimeError('Delimiter must be a string')

        if generation == 1:
            _name1 = firstgen._name1
            _name2 = firstgen._name2
        elif generation == 2:
            _name1 = secondgen._name1
            _name2 = secondgen._name2
        elif generation == 2:
            _name1 = secondgen._name1
            _name2 = secondgen._name2
        elif generation == 3:
            _name1 = thirdgen._name1
            _name2 = thirdgen._name2
        elif generation == 4:
            _name1 = fourthgen._name1
            _name2 = fourthgen._name2
        elif generation == 5:
            _name1 = fifthgen._name1
            _name2 = fifthgen._name2
        elif generation == 6:
            _name1 = sixthgen._name1
            _name2 = sixthgen._name2
        elif generation == 7:
            _name1 = seventhgen._name1
            _name2 = seventhgen._name2
        else:
            raise RuntimeError('Only generations 1-7 are supported, {0} specified'.format(generation))

        generated = [choice(_name1), choice(_name2)]
        generated = [RE_DASH.sub('', RE_WORD.sub('', g)) for g in generated]

        if digit is not None:
            if not isinstance(digit, int) or (digit < 1) or (digit < len(str(token_range))):
                raise RuntimeError('Digit must be more than 0')
            format_str = '%0.' + str(digit) + 'd'
            result = format_str % randint(0, token_range)
        else:
            result = randint(0, token_range)
        generated.append(str(result))

        result = delimiter.join(generated)
        if lowercase is True:
            result = result.lower()
        return result



# -*- coding: utf-8 -*-

_name1 = [
    'Treecko', 'Grovyle', 'Sceptile', 'Torchic', 'Combusken',
    'Blaziken', 'Mudkip', 'Marshtomp', 'Swampert', 'Poochyena',
    'Mightyena', 'Zigzagoon', 'Linoone', 'Wurmple', 'Silcoon',
    'Beautifly', 'Cascoon', 'Dustox', 'Lotad', 'Lombre',
    'Ludicolo', 'Seedot', 'Nuzleaf', 'Shiftry', 'Taillow',
    'Swellow', 'Wingull', 'Pelipper', 'Ralts', 'Kirlia',
    'Gardevoir', 'Surskit', 'Masquerain', 'Shroomish', 'Breloom',
    'Slakoth', 'Vigoroth', 'Slaking', 'Nincada', 'Ninjask',
    'Shedinja', 'Whismur', 'Loudred', 'Exploud', 'Makuhita',
    'Hariyama', 'Azurill', 'Nosepass', 'Skitty', 'Delcatty',
    'Sableye', 'Mawile', 'Aron', 'Lairon', 'Aggron', 'Meditite',
    'Medicham', 'Electrike', 'Manectric', 'Plusle', 'Minun',
    'Volbeat', 'Illumise', 'Roselia', 'Gulpin', 'Swalot',
    'Carvanha', 'Sharpedo',
]

_name2 = [
    'Wailmer', 'Wailord', 'Numel', 'Camerupt', 'Torkoal',
    'Spoink', 'Grumpig', 'Spinda', 'Trapinch', 'Vibrava',
    'Flygon', 'Cacnea', 'Cacturne', 'Swablu', 'Altaria',
    'Zangoose', 'Seviper', 'Lunatone', 'Solrock', 'Barboach',
    'Whiscash', 'Corphish', 'Crawdaunt', 'Baltoy', 'Claydol',
    'Lileep', 'Cradily', 'Anorith', 'Armaldo', 'Feebas',
    'Milotic', 'Castform', 'Kecleon', 'Shuppet', 'Banette',
    'Duskull', 'Dusclops', 'Tropius', 'Chimecho', 'Absol',
    'Wynaut', 'Snorunt', 'Glalie', 'Spheal', 'Sealeo',
    'Walrein', 'Clamperl', 'Huntail', 'Gorebyss', 'Relicanth',
    'Luvdisc', 'Bagon', 'Shelgon', 'Salamence', 'Beldum',
    'Metang', 'Metagross', 'Regirock', 'Regice', 'Registeel',
    'Latias', 'Latios', 'Kyogre', 'Groudon', 'Rayquaza',
    'Jirachi', 'Deoxys',
]



# -*- coding: utf-8 -*-

_name1 = [
    'Bulbasaur', 'Ivysaur', 'Venusaur', 'Charmander', 'Charmeleon',
    'Charizard', 'Squirtle', 'Wartortle', 'Blastoise', 'Caterpie',
    'Metapod', 'Butterfree', 'Weedle', 'Kakuna', 'Beedrill',
    'Pidgey', 'Pidgeotto', 'Pidgeot', 'Rattata', 'Raticate',
    'Spearow', 'Fearow', 'Ekans', 'Arbok', 'Pikachu',
    'Raichu', 'Sandshrew', 'Sandslash', 'Nidoran', 'Nidorina',
    'Nidoqueen', 'Nidorino', 'Nidoking', 'Clefairy', 'Clefable',
    'Vulpix', 'Ninetales', 'Jigglypuff', 'Wigglytuff', 'Zubat',
    'Golbat', 'Oddish', 'Gloom', 'Vileplume', 'Paras',
    'Parasect', 'Venonat', 'Venomoth', 'Diglett', 'Dugtrio',
    'Meowth', 'Persian', 'Psyduck', 'Golduck', 'Mankey',
    'Primeape', 'Growlithe', 'Arcanine', 'Poliwag', 'Poliwhirl',
    'Poliwrath', 'Abra', 'Kadabra', 'Alakazam', 'Machop',
    'Machoke', 'Machamp', 'Bellsprout', 'Weepinbell', 'Victreebel',
    'Tentacool', 'Tentacruel', 'Geodude', 'Graveler', 'Golem',
]

_name2 = [
    'Ponyta', 'Rapidash', 'Slowpoke', 'Slowbro', 'Magnemite',
    'Magneton', 'Farfetchd', 'Doduo', 'Dodrio', 'Seel',
    'Dewgong', 'Grimer', 'Muk', 'Shellder', 'Cloyster',
    'Gastly', 'Haunter', 'Gengar', 'Onix', 'Drowzee',
    'Hypno', 'Krabby', 'Kingler', 'Voltorb', 'Electrode',
    'Exeggcute', 'Exeggutor', 'Cubone', 'Marowak', 'Hitmonlee',
    'Hitmonchan', 'Lickitung', 'Koffing', 'Weezing', 'Rhyhorn',
    'Rhydon', 'Chansey', 'Tangela', 'Kangaskhan', 'Horsea',
    'Seadra', 'Goldeen', 'Seaking', 'Staryu', 'Starmie',
    'MrMime', 'Scyther', 'Jynx', 'Electabuzz', 'Magmar',
    'Pinsir', 'Tauros', 'Magikarp', 'Gyarados', 'Lapras',
    'Ditto', 'Eevee', 'Vaporeon', 'Jolteon', 'Flareon',
    'Porygon', 'Omanyte', 'Omastar', 'Kabuto', 'Kabutops',
    'Aerodactyl', 'Snorlax', 'Articuno', 'Zapdos', 'Moltres',
    'Dratini', 'Dragonair', 'Dragonite', 'Mewtwo', 'Mew',
]



_name1 = [
    'Rowlet', 'Dartrix', 'Decidueye', 'Litten', 'Torracat',
    'Incineroar', 'Popplio', 'Brionne', 'Primarina', 'Pikipek',
    'Trumbeak', 'Toucannon', 'Yungoos', 'Gumshoos', 'Grubbin',
    'Charjabug', 'Vikavolt', 'Crabrawler', 'Crabominable', 'Oricorio',
    'Cutiefly', 'Ribombee', 'Rockruff', 'Lycanroc', 'Wishiwashi',
    'Mareanie', 'Toxapex', 'Mudbray', 'Mudsdale', 'Dewpider',
    'Araquanid', 'Fomantis', 'Lurantis', 'Morelull', 'Shiinotic',
    'Salandit', 'Salazzle', 'Stufful', 'Bewear', 'Bounsweet',
]

_name2 = [
    'Steenee', 'Tsareena', 'Comfey', 'Oranguru', 'Passimian',
    'Wimpod', 'Golisopod', 'Sandygast', 'Palossand', 'Pyukumuku',
    'Type: Null', 'Silvally', 'Minior', 'Komala', 'Turtonator',
    'Togedemaru', 'Mimikyu', 'Bruxish', 'Drampa', 'Dhelmise',
    'Jangmo-o', 'Hakamo-o', 'Kommo-o', 'Tapu Koko', 'Tapu Lele',
    'Tapu Bulu', 'Tapu Fini', 'Cosmog', 'Cosmoem', 'Solgaleo',
    'Lunala', 'Nihilego', 'Buzzwole', 'Pheromosa', 'Xurkitree',
    'Celesteela', 'Kartana', 'Guzzlord', 'Necrozma', 'Magearna',
    'Marshadow',
]



#! /usr/bin/env python
# -*- coding: utf-8 -*-

from setuptools import setup

CLASSIFIERS = [
    'Development Status :: 5 - Production/Stable',
    'Intended Audience :: Developers',
    'License :: OSI Approved :: MIT License',
    'Operating System :: OS Independent',
    'Programming Language :: Python',
    'Programming Language :: Python :: 3',
    'Programming Language :: Python :: 3.4',
    'Programming Language :: Python :: 3.5',
    'Programming Language :: Python :: 3.6',
    'Topic :: Software Development :: Libraries :: Python Modules',
]

setup(
    name='pokinator',
    author='punkyoon',
    author_email='punkkid001@gmail.com',
    keywords='random pokemon name generator',
    description='Heroku-like random pokemon name generator for python',
    license='MIT',
    version='1.2.0',
    url='https://github.com/punkyoon/pokinator',
    packages=['pokinator', 'pokinator/pokemons'],
    test_suite='pokinator.tests',
    include_package_data=True,
    classifiers=CLASSIFIERS,
    platforms=['any']
)



# -*- coding: utf-8 -*-

_name1 = [
    'Chikorita', 'Bayleef', 'Meganium', 'Cyndaquil', 'Quilava',
    'Typhlosion', 'Totodile', 'Croconaw', 'Feraligatr', 'Sentret',
    'Furret', 'Hoothoot', 'Noctowl', 'Ledyba', 'Ledian',
    'Spinarak', 'Ariados', 'Crobat', 'Chinchou', 'Lanturn',
    'Pichu', 'Cleffa', 'Igglybuff', 'Togepi', 'Togetic',
    'Natu', 'Xatu', 'Mareep', 'Flaaffy', 'Ampharos',
    'Bellossom', 'Marill', 'Azumarill', 'Sudowoodo', 'Politoed',
    'Hoppip', 'Skiploom', 'Jumpluff', 'Aipom', 'Sunkern',
    'Sunflora', 'Yanma', 'Wooper', 'Quagsire', 'Espeon',
    'Umbreon', 'Murkrow', 'Slowking', 'Misdreavus', 'Unown',
]

_name2 = [
    'Wobbuffet', 'Girafarig', 'Pineco', 'Forretress', 'Dunsparce',
    'Gligar', 'Steelix', 'Snubbull', 'Granbull', 'Qwilfish',
    'Scizor', 'Shuckle', 'Heracross', 'Sneasel', 'Teddiursa',
    'Ursaring', 'Slugma', 'Magcargo', 'Swinub', 'Piloswine',
    'Corsola', 'Remoraid', 'Octillery', 'Delibird', 'Mantine',
    'Skarmory', 'Houndour', 'Houndoom', 'Kingdra', 'Phanpy',
    'Donphan', 'Porygon2', 'Stantler', 'Smeargle', 'Tyrogue',
    'Hitmontop', 'Smoochum', 'Elekid', 'Magby', 'Miltank',
    'Blissey', 'Raikou', 'Entei', 'Suicune', 'Larvitar',
    'Pupitar', 'Tyranitar', 'Lugia', 'Ho-Oh', 'Celebi',
]
